@@ -26,6 +26,7 @@
 
 #include "shared.h"
 
-void send_presence_for_connection (FeedContext *context);
+void context_connected (FeedContext *context);
+void context_disconnected(FeedContext *context);
 
 #endif /* _GALAGO_H */
