@@ -30,8 +30,16 @@
 #include <dbus/dbus-glib.h>
 #include <dbus/dbus-glib-lowlevel.h>
 
+#include "shared.h"
 #include "dbus.h"
 
+static const GDebugKey debug_keys[]= {
+  { "presence", DEBUG_PRESENCE },
+  { "dbus", DEBUG_DBUS },
+};
+
+guint debug_flags = 0;
+
 DBusGConnection *gconnection;
 DBusConnection *connection;
 
@@ -47,13 +55,21 @@ int
 main (int argc, char **argv)
 {
   GError *error = NULL;
+  const char *debug_string;
 
   /* Initialize glib */
   g_type_init();
   mainloop = g_main_loop_new (NULL, FALSE);
 
   g_printerr ("Starting telepathy-feed...\n");
-  
+
+  /* Initialize the debugging flags */
+  debug_string = g_getenv("TELEPATHY_FEED_DEBUG");
+  if (debug_string != NULL) {
+    debug_flags = g_parse_debug_string (debug_string, debug_keys,
+					G_N_ELEMENTS (debug_keys));
+  }
+
   /* Get a connection to the session bus */
   gconnection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
   if (gconnection == NULL) {
