@@ -31,10 +31,24 @@ extern DBusConnection *connection;
 
 typedef struct {
   TpConn *conn;
+  TpChan *chan;
   GHashTable *account_hash;
   DBusGProxy *presence_proxy;
+  DBusGProxy *group_proxy;
+  guint status;
+  guint self_handle;
+  guint list_handle;
 } FeedContext;
 
-#define d(x)
+/* Debugging flags */
+enum {
+	DEBUG_PRESENCE = 1 << 1,
+	DEBUG_DBUS = 1 << 3,
+};
+
+extern guint debug_flags;
+
+#define p_debug(f, x...) if (debug_flags & DEBUG_PRESENCE) g_debug (G_STRLOC ": " f, ##x)
+#define d_debug(f, x...) if (debug_flags & DEBUG_DBUS) g_debug (G_STRLOC ": " f, ##x)
 
 #endif /* _SHARED_H */
